GlobalConfig class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fontFamily TextStyle
no setter
imgAssetFolderPath String
no setter
networkImageCachedHeight int
no setter
networkImageCachedWidth int
no setter
svgAssetFolderPath String
no setter

Static Methods

ensureDlutterStarted({TextStyle? fontFamily, String? svgAssetFolderPath, String? imgAssetFolderPath, int? networkImgCachedWidth, int? networkImgCachedHeight}) GlobalConfig